==> haskell-gauge-0.2.5-325.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gauge.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gauge
version:              0.2.5
visibility:           public
id:                   gauge-0.2.5-Kl2v11MdDlKGHdiZiUctHv
key:                  gauge-0.2.5-Kl2v11MdDlKGHdiZiUctHv
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/vincenthz/hs-gauge
synopsis:             small framework for performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

category:             Development, Performance, Testing, Benchmarking
abi:                  d7d4a65f927e9ce0bf48dc67af8357ba
exposed:              True
exposed-modules:
    Gauge Gauge.Analysis Gauge.Benchmark Gauge.Main Gauge.Main.Options

hidden-modules:
    Gauge.IO.Printf Gauge.Measurement Gauge.Monad Gauge.ListMap
    Gauge.Time Gauge.Optional Gauge.CSV Gauge.Format
    Gauge.Source.RUsage Gauge.Source.GC Gauge.Source.Time
    System.Random.MWC Paths_gauge Statistics.Distribution
    Statistics.Distribution.Normal Statistics.Function
    Statistics.Internal Statistics.Math.RootFinding Statistics.Matrix
    Statistics.Matrix.Algorithms Statistics.Matrix.Mutable
    Statistics.Matrix.Types Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Transform Statistics.Types Statistics.Types.Internal
    Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
    Numeric.SpecFunctions Numeric.SpecFunctions.Internal Numeric.Sum

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gauge-0.2.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gauge-0.2.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gauge-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gauge
hs-libraries:         HSgauge-0.2.5-Kl2v11MdDlKGHdiZiUctHv
depends:
    base-4.18.2.1 basement-0.0.16-HvTgG10TboKKpCgs2TlMDx
    deepseq-1.4.8.1 directory-1.3.8.5 process-1.6.19.0
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-gauge/html/gauge.haddock
haddock-html:         /usr/share/doc/haskell-gauge/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gauge-0.2.5-326-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gauge.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gauge
version:              0.2.5
visibility:           public
id:                   gauge-0.2.5-1KdQFqVW7Oj4dE45j69sNh
key:                  gauge-0.2.5-1KdQFqVW7Oj4dE45j69sNh
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/vincenthz/hs-gauge
synopsis:             small framework for performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

category:             Development, Performance, Testing, Benchmarking
abi:                  f126aec680609dcafb0a18ff5970d83c
exposed:              True
exposed-modules:
    Gauge Gauge.Analysis Gauge.Benchmark Gauge.Main Gauge.Main.Options

hidden-modules:
    Gauge.IO.Printf Gauge.Measurement Gauge.Monad Gauge.ListMap
    Gauge.Time Gauge.Optional Gauge.CSV Gauge.Format
    Gauge.Source.RUsage Gauge.Source.GC Gauge.Source.Time
    System.Random.MWC Paths_gauge Statistics.Distribution
    Statistics.Distribution.Normal Statistics.Function
    Statistics.Internal Statistics.Math.RootFinding Statistics.Matrix
    Statistics.Matrix.Algorithms Statistics.Matrix.Mutable
    Statistics.Matrix.Types Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Transform Statistics.Types Statistics.Types.Internal
    Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
    Numeric.SpecFunctions Numeric.SpecFunctions.Internal Numeric.Sum

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gauge-0.2.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gauge-0.2.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gauge-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gauge
hs-libraries:         HSgauge-0.2.5-1KdQFqVW7Oj4dE45j69sNh
depends:
    base-4.18.2.1 basement-0.0.16-HvTgG10TboKKpCgs2TlMDx
    deepseq-1.4.8.1 directory-1.3.8.5 process-1.6.19.0
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-gauge/html/gauge.haddock
haddock-html:         /usr/share/doc/haskell-gauge/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
